=================================================================================================================================================================
Python Authorization Helper
=================================================================================================================================================================


.. image:: https://img.shields.io/pypi/v/pigauth.svg
        :target: https://pypi.python.org/pypi/pigauth

.. image:: https://img.shields.io/travis/ivangeorgiev/pigauth.svg
        :target: https://travis-ci.com/ivangeorgiev/pigauth

.. image:: https://readthedocs.org/projects/pigauth/badge/?version=latest
        :target: https://pigauth.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Authorization Helper for Python projects


* Free software: BSD license
* Documentation: https://pigauth.readthedocs.io.


Features
--------

* TODO

Glossary
---------

.. glossary::

    authorization scheme
        Specification of how the authorization is handled through a set of permissions
        and role definitions.

    grant
        Assignment of a role or a permission pattern which grants matching permissions
        to a user.

    pattern modifier
        Specifies how the permission pattern evaluation is to be modified.

    permission pattern
        An expression which is evaluated to match permissions.

    role
        A collection of permissions.
